@@ -36,20 +36,20 @@ import ncbi.datasets.v1.reports.microbigge_pb2 as microbigge_report_pb2
 logger = logging.getLogger(__name__)
 
 
-def get_dataset_from_file(zip_file_or_directory: str, dataset_type: str) -> 'Dataset':
+def get_dataset_from_file(zip_file_or_directory: str, dataset_type: str) -> "Dataset":
     """Create a Dataset-derived object of type 'dataset_type' and return it.
 
     Returns:
         A subclass of the class 'Dataset' as specified by the caller.
     """
 
-    if dataset_type == 'ASSEMBLY':
+    if dataset_type == "ASSEMBLY":
         return AssemblyDataset(zip_file_or_directory)
-    elif dataset_type == 'GENE':
+    elif dataset_type == "GENE":
         return GeneDataset(zip_file_or_directory)
-    elif dataset_type == 'VIRUS':
+    elif dataset_type == "VIRUS":
         return VirusDataset(zip_file_or_directory)
-    elif dataset_type == 'MICROBIGGE':
+    elif dataset_type == "MICROBIGGE":
         return MicrobiggeDataset(zip_file_or_directory)
     raise ValueError(dataset_type)
 
@@ -63,8 +63,8 @@ def _get_files_of_type(elt: Dict[str, Any], file_type: str, results: List[str])
 
     if isinstance(elt, dict):
         for k, v in elt.items():
-            if k == 'files' and isinstance(v, list):
-                results.extend([f['filePath'] for f in v if f['fileType'] == file_type])
+            if k == "files" and isinstance(v, list):
+                results.extend([f["filePath"] for f in v if f["fileType"] == file_type])
             else:
                 _get_files_of_type(v, file_type, results)
     elif isinstance(elt, list):
@@ -81,8 +81,8 @@ def _get_file_types(elt: Dict[str, Any], results: Set[str]) -> None:
 
     if isinstance(elt, dict):
         for k, v in elt.items():
-            if k == 'files' and isinstance(v, list):
-                results.update([f['fileType'] for f in v])
+            if k == "files" and isinstance(v, list):
+                results.update([f["fileType"] for f in v])
             else:
                 _get_file_types(v, results)
     elif isinstance(elt, list):
@@ -90,7 +90,7 @@ def _get_file_types(elt: Dict[str, Any], results: Set[str]) -> None:
             _get_file_types(v, results)
 
 
-class Dataset():
+class Dataset:
     """Base class to extract files from datasets package
 
     Functions to extract files from a datasets package based on file names and types
@@ -113,15 +113,15 @@ class Dataset():
         self.dataset_dir = None
 
         if os.path.isdir(zipfile_or_directory):
-            self.dataset_dir = os.path.join(zipfile_or_directory, 'data')
+            self.dataset_dir = os.path.join(zipfile_or_directory, "data")
         elif os.path.isfile(zipfile_or_directory):
             try:
-                self.dataset_zip = zipfile.ZipFile(zipfile_or_directory)    # pylint:disable=consider-using-with
-                self.dataset_dir = 'ncbi_dataset/data'
+                self.dataset_zip = zipfile.ZipFile(zipfile_or_directory)  # pylint:disable=consider-using-with
+                self.dataset_dir = "ncbi_dataset/data"
             except zipfile.BadZipFile as e:
-                logger.error('Bad zipfile: %s', e)
+                logger.error("Bad zipfile: %s", e)
         else:
-            logger.error('Invalid file or directory %s', zipfile_or_directory)
+            logger.error("Invalid file or directory %s", zipfile_or_directory)
 
     # True if Dataset is reading directly from a zip file
     def is_zipped(self) -> bool:
@@ -139,12 +139,12 @@ class Dataset():
         """Return the datasets file catalog as a dictionary"""
 
         dataset_catalog: Dict[str, Any]
-        catalog_file = self.get_file_content('dataset_catalog.json')
+        catalog_file = self.get_file_content("dataset_catalog.json")
         if catalog_file:
             try:
                 dataset_catalog = json.loads(catalog_file)
             except json.JSONDecodeError as e:
-                logger.error('Error decoding dataset_catalog file to json: %s', e)
+                logger.error("Error decoding dataset_catalog file to json: %s", e)
         return dataset_catalog
 
     def get_file_names_by_type(self, file_type: str) -> List[str]:
@@ -182,7 +182,7 @@ class Dataset():
         """Return full text of file 'file_name'"""
         with self.get_file_handle(file_name) as fh:
             if not fh:
-                return ''
+                return ""
             return fh.read()
 
     @contextlib.contextmanager
@@ -200,19 +200,19 @@ class Dataset():
         if self.dataset_zip:
             try:
                 zinfo = self.dataset_zip.getinfo(os.path.join(self.dataset_dir, file_name))
-                with io.TextIOWrapper(self.dataset_zip.open(zinfo), encoding='utf8') as fh:
+                with io.TextIOWrapper(self.dataset_zip.open(zinfo), encoding="utf8") as fh:
                     yield fh
             except KeyError as e:
-                logger.error('File %s not found in zipfile: %s', file_name, e)
+                logger.error("File %s not found in zipfile: %s", file_name, e)
         elif self.dataset_dir:
             file_path = os.path.join(self.dataset_dir, file_name)
             if os.path.exists(file_path):
-                with open(file_path, 'r', encoding='utf8') as fh:
+                with open(file_path, "r", encoding="utf8") as fh:
                     yield fh
             else:
-                logger.error('File not found in datasets directory: %s', file_path)
+                logger.error("File not found in datasets directory: %s", file_path)
         else:
-            logger.error('Dataset not available - unable to load: %s', file_name)
+            logger.error("Dataset not available - unable to load: %s", file_name)
 
     def stream_reports(self, file_type: str, protobuf_report_type: Any) -> Any:
         """Retrieve report records defined via protobuf schema from jsonl files.
@@ -237,7 +237,7 @@ class Dataset():
                         ParseDict(json_dict, protobuf_rpt, ignore_unknown_fields=False)
                         yield protobuf_rpt
                     except (SerializeToJsonError, ParseError) as e:
-                        logger.error('Error converting json to schema: %s', e)
+                        logger.error("Error converting json to schema: %s", e)
 
 
 class AssemblyDataset(Dataset):
@@ -252,7 +252,7 @@ class AssemblyDataset(Dataset):
         Returns:
           Yields a set of AssemblyDataReport protobuf objects
         """
-        yield from self.stream_reports('DATA_REPORT', assembly_report_pb2.AssemblyDataReport)
+        yield from self.stream_reports("DATA_REPORT", assembly_report_pb2.AssemblyDataReport)
 
     def get_sequence_reports(self) -> Iterator[sequence_report_pb2.SequenceInfo]:
         """Retrieve assembly sequence reports
@@ -260,7 +260,7 @@ class AssemblyDataset(Dataset):
         Returns:
           Yields a set of Assembly SequenceInfo protobuf objects
         """
-        yield from self.stream_reports('SEQUENCE_REPORT', sequence_report_pb2.SequenceInfo)
+        yield from self.stream_reports("SEQUENCE_REPORT", sequence_report_pb2.SequenceInfo)
 
 
 class GeneDataset(Dataset):
@@ -275,7 +275,7 @@ class GeneDataset(Dataset):
         Returns:
            Yields a set of GeneDescriptor protobuf objects
         """
-        yield from self.stream_reports('DATA_REPORT', gene_report_pb2.GeneDescriptor)
+        yield from self.stream_reports("DATA_REPORT", gene_report_pb2.GeneDescriptor)
 
 
 class VirusDataset(Dataset):
@@ -290,7 +290,7 @@ class VirusDataset(Dataset):
         Returns:
           Yields a set of virus assembly report protobuf objects
         """
-        yield from self.stream_reports('DATA_REPORT', virus_report_pb2.VirusAssembly)
+        yield from self.stream_reports("DATA_REPORT", virus_report_pb2.VirusAssembly)
 
 
 class MicrobiggeDataset(Dataset):
@@ -305,4 +305,4 @@ class MicrobiggeDataset(Dataset):
         Returns:
           Yields a set of MicroBigge report protobuf objects
         """
-        yield from self.stream_reports('DATA_REPORT', microbigge_report_pb2.MicroBiggeReport)
+        yield from self.stream_reports("DATA_REPORT", microbigge_report_pb2.MicroBiggeReport)
